Agent Builder
shareAI-lab/learn-claude-code
Design and build AI agents for any domain. An agent skill from shareAI-lab/learn-claude-code.
Agent skill
Optimize irregular KV-cache access in Triton-Ascend grouped decode attention by vector-loading contiguous inner dimensions, assembling discrete outer rows with CANN slice extensions, and transposing…
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill optimize-triton-ascend-grouped-attention-access -a claude-codeProject install by default; add -g for ~/.claude/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit optimize-triton-ascend-grouped-attention-access --agent claude-codeProject scope by default; add --scope user for a personal install. Needs GitHub CLI 2.90.0 or later (public preview).
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .claude/skills && cp -r skills-src/skills/optimize-triton-ascend-grouped-attention-access .claude/skills/optimize-triton-ascend-grouped-attention-access && rm -rf skills-srcUse ~/.claude/skills/ instead of .claude/skills for a personal install. The folder must contain SKILL.md.
Claude Code skills documentation · loads skills from .claude/skills/
Install the "optimize-triton-ascend-grouped-attention-access" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/optimize-triton-ascend-grouped-attention-access into .claude/skills/optimize-triton-ascend-grouped-attention-access/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "optimize-triton-ascend-grouped-attention-access", then confirm the skill loads.Claude Code copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$skill-installer install https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/optimize-triton-ascend-grouped-attention-accessType this inside Codex. $skill-installer <name> installs a curated skill from openai/skills. The installer writes to $CODEX_HOME/skills (default ~/.codex/skills). Restart Codex if the skill does not show up.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill optimize-triton-ascend-grouped-attention-access -a codexProject install goes to .agents/skills/; add -g for ~/.codex/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit optimize-triton-ascend-grouped-attention-access --agent codexProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .agents/skills && cp -r skills-src/skills/optimize-triton-ascend-grouped-attention-access .agents/skills/optimize-triton-ascend-grouped-attention-access && rm -rf skills-srcUse ~/.agents/skills/ instead of .agents/skills for a personal install.
Codex skills documentation · loads skills from .agents/skills/
Install the "optimize-triton-ascend-grouped-attention-access" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/optimize-triton-ascend-grouped-attention-access into .agents/skills/optimize-triton-ascend-grouped-attention-access/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "optimize-triton-ascend-grouped-attention-access", then confirm the skill loads.Codex copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill optimize-triton-ascend-grouped-attention-access -a cursorProject install goes to .agents/skills/; add -g for ~/.cursor/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit optimize-triton-ascend-grouped-attention-access --agent cursorProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .cursor/skills && cp -r skills-src/skills/optimize-triton-ascend-grouped-attention-access .cursor/skills/optimize-triton-ascend-grouped-attention-access && rm -rf skills-srcUse ~/.cursor/skills/ instead of .cursor/skills for a personal install.
Cursor skills documentation · loads skills from .cursor/skills/, .agents/skills/, .claude/skills/, .codex/skills/
Install the "optimize-triton-ascend-grouped-attention-access" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/optimize-triton-ascend-grouped-attention-access into .cursor/skills/optimize-triton-ascend-grouped-attention-access/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "optimize-triton-ascend-grouped-attention-access", then confirm the skill loads.Cursor copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ gemini skills install https://github.com/Krusty84/triton-ascend-agent-dev-kit.git --path skills/optimize-triton-ascend-grouped-attention-access--scope user (default) or --scope workspace; --path is the subfolder of the repo that holds the skill; --consent skips the security confirmation prompt.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill optimize-triton-ascend-grouped-attention-access -a gemini-cliProject install goes to .agents/skills/; add -g for ~/.gemini/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit optimize-triton-ascend-grouped-attention-access --agent gemini-cliProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .gemini/skills && cp -r skills-src/skills/optimize-triton-ascend-grouped-attention-access .gemini/skills/optimize-triton-ascend-grouped-attention-access && rm -rf skills-srcUse ~/.gemini/skills/ instead of .gemini/skills for a personal install, then run /skills reload.
Gemini CLI skills documentation · loads skills from .gemini/skills/, .agents/skills/
Install the "optimize-triton-ascend-grouped-attention-access" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/optimize-triton-ascend-grouped-attention-access into .gemini/skills/optimize-triton-ascend-grouped-attention-access/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "optimize-triton-ascend-grouped-attention-access", then confirm the skill loads.Gemini CLI copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit optimize-triton-ascend-grouped-attention-accessInstalls for Copilot at project scope by default; add --scope user for a personal install. Preview a skill first with gh skill preview. Needs GitHub CLI 2.90.0 or later (public preview).
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill optimize-triton-ascend-grouped-attention-access -a github-copilotProject install goes to .agents/skills/; add -g for ~/.copilot/skills/.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .github/skills && cp -r skills-src/skills/optimize-triton-ascend-grouped-attention-access .github/skills/optimize-triton-ascend-grouped-attention-access && rm -rf skills-srcUse ~/.copilot/skills/ instead of .github/skills for a personal install. Commit .github/skills so cloud agent and code review can use it.
GitHub Copilot skills documentation · loads skills from .github/skills/, .claude/skills/, .agents/skills/
Install the "optimize-triton-ascend-grouped-attention-access" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/optimize-triton-ascend-grouped-attention-access into .github/skills/optimize-triton-ascend-grouped-attention-access/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "optimize-triton-ascend-grouped-attention-access", then confirm the skill loads.GitHub Copilot copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill optimize-triton-ascend-grouped-attention-access -a opencodeOpenCode documents no install command of its own. Project install goes to .agents/skills/; add -g for ~/.config/opencode/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit optimize-triton-ascend-grouped-attention-access --agent opencodeProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .opencode/skills && cp -r skills-src/skills/optimize-triton-ascend-grouped-attention-access .opencode/skills/optimize-triton-ascend-grouped-attention-access && rm -rf skills-srcUse ~/.config/opencode/skills/ instead of .opencode/skills for a personal install.
OpenCode skills documentation · loads skills from .opencode/skills/, .claude/skills/, .agents/skills/
Install the "optimize-triton-ascend-grouped-attention-access" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/optimize-triton-ascend-grouped-attention-access into .opencode/skills/optimize-triton-ascend-grouped-attention-access/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "optimize-triton-ascend-grouped-attention-access", then confirm the skill loads.OpenCode copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
optimize-triton-ascend-grouped-attention-accessOptimize irregular KV-cache access in Triton-Ascend grouped decode attention by vector-loading contiguous inner dimensions, assembling discrete outer rows with CANN slice extensions, and transposing…
Optimize Triton Ascend Grouped Attention Access is an agent skill from Krusty84/triton-ascend-agent-dev-kit. Optimize irregular KV-cache access in Triton-Ascend grouped decode attention by vector-loading contiguous inner dimensions, assembling discrete outer rows with CANN slice extensions, and transposing UB tiles for tl.dot. Use when an agent ports grouped-query decode attention whose K or V cache addresses are indirect and naive low-axis-discrete loads degrade to scalar memory access.
Its SKILL.md is about 660 tokens, which your agent loads only when the skill is triggered. It is a single SKILL.md file with no bundled scripts.
It sits in AI & LLM Engineering. The repository describes itself as: A toolkit for AI agents used for development on Triton-Ascend for Ascend NPU. The licence is Apache-2.0.
6 steps, taken from the first numbered list in SKILL.md.
Read from SKILL.md and the folder at commit 4ab5ee7. It shows what the files ask for, not the result of running them.
Pre-approves nothing: there is no allowed-tools line, so your agent's usual permission prompts apply.
From allowed-tools in the SKILL.md frontmatter.
No scripts in the folder and no shell commands in SKILL.md (its code samples are python).
From the folder's file list and the shell code blocks in SKILL.md.
No URLs in SKILL.md.
From URLs in SKILL.md, links to its own repository left out.
Names no API keys, tokens, secrets or passwords.
From names ending in _API_KEY, _TOKEN, _SECRET, _KEY or _PASSWORD in SKILL.md.
Optimize Triton Ascend Grouped Attention Access loads about 658 tokens when it runs. Until then it costs about 108 tokens; SKILL.md has 207 words of instructions outside code blocks.
Estimates: characters ÷ 4, the usual rule of thumb; real counts depend on the model's tokenizer. Scripts and assets cost tokens only if the agent reads them.
The automated check found no risky patterns in SKILL.md.
Automated static check — not a guarantee. Review scripts before installing. It scans the text of SKILL.md for risky patterns (piping downloads into a shell, reading credential files, hidden Unicode, destructive commands); files beside SKILL.md are not scanned.
The full file from Krusty84/triton-ascend-agent-dev-kit at commit 4ab5ee7, republished under its Apache-2.0 licence (© Krusty84). 207 words, ~658 tokens.
.claude/skills/optimize-triton-ascend-grouped-attention-access/SKILL.md (or your agent's skills folder).Preserve vectorized contiguous loads while gathering KV-cache rows selected by an indirect token-location vector.
import triton.language.extra.cann.extension as extension
k_rows = tl.zeros((BLOCK_N, BLOCK_DMODEL), dtype=q.dtype)
for i in range(0, BLOCK_N):
if start_n + i < split_kv_end:
cache_row = extension.get_element(kv_locations, (i,))
offsets = (
cache_row * stride_k_token
+ kv_head * stride_k_head
+ tl.arange(0, BLOCK_DMODEL)
)
row = tl.load(K + offsets, mask=tl.arange(0, BLOCK_DMODEL) < key_dim)
k_rows = extension.insert_slice(
k_rows, row[None, :], (i, 0), (1, BLOCK_DMODEL), (1, 1)
)
k = tl.trans(k_rows, (1, 0))
scores = tl.dot(q, k.to(q.dtype))Compare with a PyTorch or trusted fused-attention reference across variable sequence lengths, KV splits, grouped-head ratios, optional positional feature dimensions, and partial BLOCK_N tails.
© Krusty84, Apache-2.0. Rendered from Markdown: HTML in the file is shown as text, images as links, and headings moved down two levels. Raw file
Just SKILL.md in skills/optimize-triton-ascend-grouped-attention-access of Krusty84/triton-ascend-agent-dev-kit.
Open the folder on GitHubat commit 4ab5ee7
Optimize Triton Ascend Grouped Attention Access next to the 5 skills that share the most tags, products or categories with it. Stars are the repository's; “used in” counts other GitHub owners with a copy.
| Skill | Stars | Used in | Tokens | Auto-check | Licence | Repo updated |
|---|---|---|---|---|---|---|
| Optimize Triton Ascend Grouped Attention Access this skillKrusty84/triton-ascend-agent-dev-kit | 106 | — | ~658 | Automated safety check: Pass | Apache-2.0 | |
| Agent BuildershareAI-lab/learn-claude-code | 78k | 4 repos | ~1.2k | Automated safety check: Pass | MIT | |
| Add Uint Supportpytorch/pytorch | 104k | 2 repos | ~2.3k | Automated safety check: Pass | Custom licence | |
| LLM Benchmarking with lm-evaluation-harnessOrchestra-Research/AI-Research-SKILLs | 13k | 8 repos | ~3k | Automated safety check: Pass | MIT | |
| Segment Anything Model GuideOrchestra-Research/AI-Research-SKILLs | 13k | 8 repos | ~3.3k | Automated safety check: Pass | MIT | |
| 1passwordtrpc-group/trpc-agent-go | 1.9k | 14 repos | ~656 | Automated safety check: Pass | Apache-2.0 |
shareAI-lab/learn-claude-code
Design and build AI agents for any domain. An agent skill from shareAI-lab/learn-claude-code.
pytorch/pytorch
Add unsigned integer (uint) type support to PyTorch operators by updating ATDISPATCH macros.
Orchestra-Research/AI-Research-SKILLs
Runs lm-evaluation-harness to benchmark language models on academic suites such as MMLU, GSM8K and HumanEval, compare models and track training checkpoints.
Orchestra-Research/AI-Research-SKILLs
Guide to using Meta's Segment Anything Model for zero-shot image segmentation with point, box or mask prompts, or automatic mask generation.
trpc-group/trpc-agent-go
Set up and use 1Password CLI (op). An agent skill from trpc-group/trpc-agent-go.
jarrodwatts/claude-code-config
Transforms workflow to use Manus-style persistent markdown files for planning, progress tracking, and knowledge storage.
Krusty84/triton-ascend-agent-dev-kit
Implements request-to-token-pool copies for Triton kernels on Ascend NPUs, replacing loop-carried vector offsets with fixed-offset block loops that compile reliably.
Krusty84/triton-ascend-agent-dev-kit
Writes a Triton kernel pattern for Ascend NPU that gathers several indexed token rows per program into an on-chip buffer and stores one contiguous output tile, for MoE-style token reordering.
Krusty84/triton-ascend-agent-dev-kit
Builds Triton-Ascend kernels that pack sorted token assignments into fixed expert-capacity tensors, restore top-k outputs and compute router-weight gradients on Ascend NPUs.
Krusty84/triton-ascend-agent-dev-kit
Guides building a FlashAttention-v2-style fused forward attention kernel for Triton-Ascend on Ascend NPU, with online softmax, causal staging and float32 accumulation.
Krusty84/triton-ascend-agent-dev-kit
Builds a fused row-wise softmax kernel for Triton-Ascend that reads and writes each row once, handling padding, strides and masked loads on Ascend NPUs.
Krusty84/triton-ascend-agent-dev-kit
Build a fused forward LayerNorm kernel for Triton-Ascend with row-wise mean and variance reductions, float32 accumulation, affine weight and bias, and masked feature tiles.
Categories
Optimize irregular KV-cache access in Triton-Ascend grouped decode attention by vector-loading contiguous inner dimensions, assembling discrete outer rows with CANN slice extensions, and transposing…. Optimize Triton Ascend Grouped Attention Access is an agent skill from Krusty84/triton-ascend-agent-dev-kit.dot.
Optimize Triton Ascend Grouped Attention Access fits situations like: an agent ports grouped-query decode attention whose K; V cache addresses are indirect and naive low-axis-discrete loads degrade to scalar memory access.
Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill optimize-triton-ascend-grouped-attention-access -a claude-code`. Or copy the skill folder (skills/optimize-triton-ascend-grouped-attention-access in Krusty84/triton-ascend-agent-dev-kit) into .claude/skills/optimize-triton-ascend-grouped-attention-access in your project. Claude Code loads it when a task matches its description.
Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill optimize-triton-ascend-grouped-attention-access -a codex`. Or copy the skill folder (skills/optimize-triton-ascend-grouped-attention-access in Krusty84/triton-ascend-agent-dev-kit) into .agents/skills/optimize-triton-ascend-grouped-attention-access in your project. Codex loads it when a task matches its description.
Cursor, Gemini CLI, GitHub Copilot and OpenCode also load SKILL.md folders. With the skills CLI, run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill optimize-triton-ascend-grouped-attention-access -a cursor` (or -a gemini-cli, github-copilot or opencode for the others). To copy it by hand, put the folder in .cursor/skills/optimize-triton-ascend-grouped-attention-access, .gemini/skills/optimize-triton-ascend-grouped-attention-access, .github/skills/optimize-triton-ascend-grouped-attention-access and .opencode/skills/optimize-triton-ascend-grouped-attention-access in your project.
SKILL.md names no scripts, command-line tools or credentials: Optimize Triton Ascend Grouped Attention Access is instructions for the agent only. Our summary lists: Python 3.
SKILL.md contains no URLs. Any network use would come from the scripts or tools the agent runs. This is read from the text; nothing was executed.
Our automated static check of SKILL.md found no risky patterns, such as piping downloads into a shell, reading credential files or hidden Unicode. It is not a guarantee. Review the folder before installing.
Optimize Triton Ascend Grouped Attention Access is published under the Apache-2.0 licence (the repository's licence). It allows redistribution, so the full SKILL.md is shown on this page.
About 658 tokens (SKILL.md is roughly 2.6k characters). Agents keep only the skill's name and description in context until a task matches; then they load SKILL.md in full.
Skills that share tags, products or a category with Optimize Triton Ascend Grouped Attention Access: Agent Builder (shareAI-lab/learn-claude-code, 78k stars), Add Uint Support (pytorch/pytorch, 104k stars), LLM Benchmarking with lm-evaluation-harness (Orchestra-Research/AI-Research-SKILLs, 13k stars) and Segment Anything Model Guide (Orchestra-Research/AI-Research-SKILLs, 13k stars). The comparison table on this page puts their stars, adoption, token cost, safety result and licence side by side.
Krusty84 (a GitHub user) maintains it in Krusty84/triton-ascend-agent-dev-kit, which has 106 GitHub stars. The repository holds 23 skills in this directory. The repository was last updated on August 15, 2026.
Source: Krusty84/triton-ascend-agent-dev-kit on GitHub. Facts on this page come from the repository at the commit we read; the author's words are quoted as theirs.